// import {FormSchema} from '@/components/Table';
import {treeOptionsListApi} from "@/api/demo/tree";
import {areaRecord} from "@/api/demo/cascader";
import dayjs from "dayjs";
import {optionsListApi} from "@/api/demo/select";
import {Input, FormItem, FormItemRest} from "ant-design-vue";
import { ApiSelect, FormSchema } from '@/components/Form';

import companyType from './drawer-form/companyType';
import annualPurchaseAmount from './drawer-form/annualPurchaseAmount';
import timeZone from './drawer-form/timeZone';
import {uploadApi} from "@/api/sys/upload";

// const custom_typeKey2typeValueRules = (model) => {
//   return [
//     {
//       // required: true,
//       // trigger: 'blur',
//       validator: async () => {
//         Logger.log('custom_typeKey2typeValueRules', model);
//         if (!model.typeKey) return Promise.reject('请选择类型');
//         if (!model.typeValue) return Promise.reject('请输入数据');
//         Promise.resolve();
//       },
//     },
//   ];
// };

export const schemas: FormSchema[] = [
  {
    field: 'field001',
    component: 'Input',
    label: '公司网址(可通过网址/公司名称自动匹配客户信息)',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'cluesName',
    component: 'Input',
    label: '公司名称',
    colProps: {
      span: 24,
    },
    rules: [{required: true, trigger: 'blur'}],
  },
  {
    field: 'field8',
    component: 'ApiCascader',
    label: '国家地区',
    colProps: {
      span: 16,
    },
    componentProps: {
      api: areaRecord,
      apiParamKey: 'parentCode',
      // dataField: 'data',
      labelField: 'name',
      valueField: 'code',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
    rules: [{required: true, trigger: 'blur'}],
  },

  {
    field: 'customerFrom',
    component: 'ApiTreeSelect',
    label: '客户来源',
    componentProps: {
      api: treeOptionsListApi,
      treeCheckable: true,
      treeCheckStrictly: true, // 父子节点是否不再关联
      resultField: 'list',
      onChange: (e, v) => {
        console.log('ApiTreeSelect====>:', e, v);
      },
    },
    colProps: {
      span: 24,
    },
    rules: [{required: true, trigger: 'blur'}],
  },

  // {
  //   field: 'field9',
  //   component: 'ApiCascader',
  //   label: '联动ApiCascader',
  //   required: true,
  //   colProps: {
  //     span: 8,
  //   },
  //   componentProps: {
  //     api: areaRecord,
  //     apiParamKey: 'parentCode',
  //     // dataField: 'data',
  //     labelField: 'name',
  //     valueField: 'code',
  //     initFetchParams: {
  //       parentCode: '',
  //     },
  //     isLeaf: (record) => {
  //       return !(record.levelType < 3);
  //     },
  //     onChange: (e, ...v) => {
  //       console.log('ApiCascader====>:', e, v);
  //     },
  //   },
  // },
  {
    field: 'field30',
    component: 'ApiSelect',
    label: '客户标签',
    // required: true,
    componentProps: {
      // more details see /src/components/Form/src/components/ApiSelect.vue
      api: optionsListApi,
      params: {
        id: 1,
      },
      mode: 'multiple',
      resultField: 'list',
      // use name as label
      labelField: 'name',
      // use id as value
      valueField: 'id',
      // not request untill to select
      immediate: true,
      onChange: (e, v) => {
        console.log('ApiSelect====>:', e, v);
      },
      // atfer request callback
      onOptionsChange: (options) => {
        // console.log('get options', options.length, options);
      },
    },
    colProps: {
      span:24,
    },
    // defaultValue: '0',
  },
  {
    field: 'customerGrouping',
    component: 'ApiTreeSelect',
    label: '客户分组',
    componentProps: {
      api: treeOptionsListApi,
      // treeCheckable: true,
      treeCheckStrictly: true, // 父子节点是否不再关联
      resultField: 'list',
      onChange: (e, v) => {
        console.log('ApiTreeSelect====>:', e, v);
      },
    },
    colProps: {
      span: 24,
    },
    rules: [{required: true, trigger: 'blur'}],
  },
  {
    field: 'customerStage',
    component: 'ApiSelect',
    label: '客户阶段',
    // required: true,
    componentProps: {
      // more details see /src/components/Form/src/components/ApiSelect.vue
      api: optionsListApi,
      params: {
        id: 1,
      },
      mode: 'multiple',
      resultField: 'list',
      // use name as label
      labelField: 'name',
      // use id as value
      valueField: 'id',
      // not request untill to select
      immediate: true,
      onChange: (e, v) => {
        console.log('ApiSelect====>:', e, v);
      },
      // atfer request callback
      onOptionsChange: (options) => {
        // console.log('get options', options.length, options);
      },
    },
    colProps: {
      span:24,
    },
    // defaultValue: '0',
  },
  {
    field: 'customerNumber',
    component: 'RadioGroup',
    defaultValue: '0',
    label: '客户编号',
    componentProps: {
      options: [
        {label: '自动生成', value: '0'},
        {label: '自定义', value: '1'},
      ],
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'customerRate',
    component: 'Rate',
    label: '客户评分',
    componentProps: {
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'field002',
    component: 'Input',
    label: '客户代码(与生产单的客户代码一致)',
    colProps: {
      span: 24,
    },
  },
  {
    component: 'Select',
    label: '客户类型',
    field: 'customerType',
    colProps: {span: 24},
    componentProps: {
      options: [
        {
          label: '原材料供应商',
          value: '1',
        },
        {
          label: '生产商',
          value: '2',
        },
        {
          label: '加盟商',
          value: '3',
        },
        {
          label: '渠道商',
          value: '4',
        },
        {
          label: '贸易商',
          value: '5',
        },
        {
          label: '代理商',
          value: '6',
        },
        {
          label: '批发商',
          value: '7',
        },
      ],
    },
    rules: [{required: true, trigger: 'blur'}],
  },
  {
    component: 'Select',
    label: '公海分组',
    field: 'publicPoolGroup',
    colProps: {span: 16},
    componentProps: {
      options: [
        {
          label: '未知',
          value: '1',
        },
        {
          label: '公共公海分组',
          value: '2',
        },
      ],
    },
    rules: [{required: true, trigger: 'blur'}],
  },
  {
    field: 'typeKey',
    defaultValue: '',
    fields: ['typeValue'],
    defaultValueObj: {typeValue: ''},
    component: 'Input',
    // label: 'renderColContent渲染',
    /**!!!renderColContent 没有FormItem 包裹, 若想要 Form 提交需要带上数据须 <FormItem name={}></FormItem> 包裹： 示例如下*/
    renderColContent({model, field}, {disabled}) {
      return (
        <FormItem
          name="typeKey"
          label="座机"
          // rules={[{ trigger: 'blur',required: true, }]}
          // rules={custom_typeKey2typeValueRules(model)}
        >
          <Input.Group compact>
            <ApiSelect
              style="width: 120px"
              v-model:api={optionsListApi}
              showSearch
              v-model:value={model['field']}
              optionFilterProp="label"
              resultField="list"
              labelField="name"
              valueField="id"
            />
            <FormItemRest>
              <Input
                style="width: calc(100% - 120px); margin-left: -1px;"
                placeholder="电话号码"
                v-model:value={model['typeValue']}
                disabled={disabled}
                // rules={[{ type: 'number',trigger: 'blur',required: true, }]}
                // rules={custom_typeKey2typeValueRules(model)}
              />
            </FormItemRest>
          </Input.Group>
        </FormItem>
      );
    },
    colProps: {
      span: 16,
    },
    dynamicDisabled: ({values}) => {
      return !!values.field_disabled;
    },
  },
  {
    field: 'salesman',
    component: 'Input',
    label: '业务员',
    colProps: {
      span: 24,
    },
    rules: [{required: true, trigger: 'blur'}],
  },
  {
    field: '',
    defaultValue: '',
    component: 'Input',
    // label: 'renderColContent渲染',
    /**!!!renderColContent 没有FormItem 包裹, 若想要 Form 提交需要带上数据须 <FormItem name={}></FormItem> 包裹： 示例如下*/
    renderColContent({model, field}, {disabled}) {
      return (
        <div class="font-size-16px mb-10px">公司其他信息</div>
      );
    },
    colProps: {
      span: 24,
    },
  },
  {
    component: 'Select',
    label: '公司类型',
    field: 'companyType',
    colProps: {span: 16},
    componentProps: {
      options: companyType,
    },
    defaultValue: '1'
  },
  {
    component: 'Select',
    label: '时区',
    field: 'timeZone',
    colProps: {span: 16},
    componentProps: {
      options: timeZone,
    },
  },
  {
    component: 'Select',
    label: '采购意向',
    field: 'purchasingIntention',
    colProps: {span: 16},
    componentProps: {
      options: [
        {
          label: '未知',
          value: '1',
        },
        {
          label: '低',
          value: '2',
        },
        {
          label: '中',
          value: '3',
        },
        {
          label: '高',
          value: '4',
        },
      ],
    },
  },
  {
    component: 'Select',
    label: '年采购额',
    field: 'annualPurchaseAmount',
    colProps: {span: 16},
    componentProps: {
      options: annualPurchaseAmount,
    },
  },
  {
    field: 'productGrouping',
    component: 'ApiTreeSelect',
    label: '产品分组',
    componentProps: {
      api: treeOptionsListApi,
      treeCheckable: true,
      treeCheckStrictly: true, // 父子节点是否不再关联
      resultField: 'list',
      onChange: (e, v) => {
        console.log('ApiTreeSelect====>:', e, v);
      },
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'detailedAddress',
    component: 'Input',
    label: '详细地址',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'cluesNotes',
    component: 'InputTextArea',
    label: '公司备注',
    colProps: {
      span: 24,
    },
  },
];
